import pickle
import pandas as pd
import numpy as np
import copy
import os

def kcal2eV(x):
    return np.array(x)*0.043364115309


#-----H2 on Cu-----------
#run the helper scripts
folder = 'analysis_figures_tables/helper/'
files = ['H2onCu_DFT.py', 'H2onCu_HSE.py', 'H2onCu_RPA.py']
for fname in files:
    print("#---------------------------------------------------------------------")
    print("#            executing {}".format(folder+fname))
    print("#---------------------------------------------------------------------")
    with open(folder+fname) as f:
        exec(f.read())

#collect the data
H2onCu={}
refH2onCu={}
files = ['H2onCu_DFT.pkl', 'H2onCu_HSE.pkl', 'H2onCu_RPA.pkl']
for fname in files:
    f=open(fname, 'rb')
    new = pickle.load(f)
    f.close()
    os.remove(fname)
    #write reference
    ref = copy.deepcopy(new)
    for val in ref:
        if not np.isnan(ref[val]):
            ref[val]=1
        else:
            ref[val]=""
    H2onCu.update(new)
    refH2onCu.update(ref)
refH2onCu['ms-b86bl']=""


#-----H2 on Al-----------
#run the helper scripts
folder = 'analysis_figures_tables/helper/'
files = ['H2onAl_DFT.py', 'H2onAl_HSE06.py', 'H2onAl_HSE06x0.33.py', 'H2onAl_RPA.py']
for fname in files:
    print("#---------------------------------------------------------------------")
    print("#            executing {}".format(folder+fname))
    print("#---------------------------------------------------------------------")
    with open(folder+fname) as f:
        exec(f.read())

#collect the data for RPA, HSE and M06L
H2onAl={}
refH2onAl={}
files = ['H2onAl_DFT.pkl', 'H2onAl_HSE06.pkl', 'H2onAl_HSE06x0.33.pkl', 'H2onAl_RPA.pkl']
for fname in files:
    f=open(fname, 'rb')
    new = pickle.load(f)
    f.close()
    os.remove(fname)
    #write reference
    ref = copy.deepcopy(new)
    print(fname)
    print(ref)
    for val in ref:
        for i,entry in enumerate(ref[val]):
            if not np.isnan(entry):
                ref[val][i]=1
            else:
                ref[val][i]=""
    H2onAl.update(new)
    refH2onAl.update(ref)


#input additional data from Powell et al (2020): J. Chem. Phys. 153, 224701 (2020), https://doi.org/10.1063/5.0022919
#DFT: extracted from data-for-pubs.xlsx Tab Fig S11 directly in eV (achieved by setting conversion factors to 1)
#DMC: extracted from same table, but using value in kcal/mol (as no eV value is availabe there)
H2onAl['dmc']=kcal2eV([25.11633615,26.65047485,35.13023223,36.59724889,33.69272839,46.97399232])
H2onAl['beef-vdw']=[1.05491323, 1.07547458, 1.52234517, 1.52582526, 1.42579513, 2.00351732]
H2onAl['rpbe-vdw-df']=[1.07680536, 1.09147271, 1.63012860, 1.57074341, 1.49436878, 2.08448041]
H2onAl['rpbe']=[1.03937288, 1.03110924, 1.42909989, 1.46903220, 1.37153161, 1.90231381]
H2onAl['ms-b86bl']=[0.98909723, 1.00653258, 1.42710748, 1.45900507, 1.31417036, 1.91032570]
H2onAl['revtpss']=[0.92118964, 1.05757976, 1.37277758, 1.49050352, 1.24765110, 1.92633467]
H2onAl['pbe-vdw-df']=[0.87596991, 0.91212044, 1.37948236, 1.40167490, 1.26534386, 1.86115460]
H2onAl['pbe']=[0.82715246, 0.84414136, 1.17065609, 1.29145904, 1.13186510, 1.67125506]
H2onAl['scan']=[0.79613849, 0.82935900, 1.15543842, 1.26937042, 1.11030201, 1.67553563]
#add reference
for i in ['dmc', 'beef-vdw', 'rpbe-vdw-df', 'rpbe', 'ms-b86bl', 'revtpss', 'pbe-vdw-df', 'pbe', 'scan']:
    refH2onAl[i]=[2,2,2,2,2,2]

#input additional data from Doblhoff et al(2017): J. Chem. Theory Comput. 2017, 13, 7, 3208–3219, https://doi.org/10.1021/acs.jctc.7b00344
H2onCu['dmc']=kcal2eV(13.0) #using the value without systematic corrections to allow for a direct comparison with the RPA values
#add reference
refH2onCu['dmc']=3

#experimental reference data as taken from SI which make use of 
#Powell et al (2024): J. Phys. Chem. Lett. 2024, 15, 1, 307–315, https://doi.org/10.1021/acs.jpclett.3c02972 and
#Diaz et al (200(): SCIENCE, 2009, 326, 5954, 832, DOI: 10.1126/science.1178722
H2onCu['exp']=[0.632]
H2onAl['exp']=[1.15, np.nan, np.nan, np.nan, np.nan, np.nan]
#add references
refH2onCu['exp'] = ["4"]
refH2onAl['exp'] = ["5","","","","",""]

#collect all data
barriersAl = pd.DataFrame(H2onAl, index = ["H2+Al: TS1", "H2+Al: TS2", "H2+Al: TS3", "H2+Al: TS4", "H2+Al: TS5", "H2+Al: TS6"])
barriersCu = pd.DataFrame(H2onCu, index = ["H2+Cu: TS1"])
barriers = pd.concat([barriersAl, barriersCu])
refsAl = pd.DataFrame(refH2onAl, index = ["H2+Al: TS1", "H2+Al: TS2", "H2+Al: TS3", "H2+Al: TS4", "H2+Al: TS5", "H2+Al: TS6"])
refsCu = pd.DataFrame(refH2onCu, index = ["H2+Cu: TS1"])
refs = pd.concat([refsAl, refsCu])
#change to correct names for functionals
barriers = barriers.rename(columns={"pbe": "PBE", "rpbe": "RPBE", "pbe-vdw-df": "PBE-vdW-DF", "rpbe-vdw-df": "RPBE-vdW-DF", "scan": "SCAN", "revtpss": "revTPSS", "ms-b86bl": "MS-B86bl", "beef-vdw": "BEEF-vdW", "m06l": "M06L", "hse06": "HSE06", "hse06x0.33": "HSE06-0.33X", "dmc": "DMC", "rpa": "RPA"})
#sort into order I want
colsSorted = ['exp','DMC','RPA', 'HSE06','HSE06-0.33X', 'SCAN','PBE','PBE-vdW-DF','revTPSS','MS-B86bl','RPBE','BEEF-vdW','RPBE-vdW-DF','M06L']
barriers = barriers[colsSorted]
refs = refs.rename(columns={"pbe": "PBE", "rpbe": "RPBE", "pbe-vdw-df": "PBE-vdW-DF", "rpbe-vdw-df": "RPBE-vdW-DF", "scan": "SCAN", "revtpss": "revTPSS", "ms-b86bl": "MS-B86bl", "beef-vdw": "BEEF-vdW", "m06l": "M06L", "hse06": "HSE06", "hse06x0.33": "HSE06-0.33X", "dmc": "DMC", "rpa": "RPA"})
refs = refs[colsSorted]


print("#---------------------------------------------------------------------")
print("#                        SUMMARY")
print("#---------------------------------------------------------------------")
with pd.option_context('display.max_rows', None, 'display.max_columns', None, 'display.width', 200):
    print("DATA:")
    print(barriers)
    print("")
    print("REFERENCES:")
    print(refs)
references = """[1] this work (linked publication)
[2] Powell et al, J. Chem. Phys. 153, 224701 (2020), https://doi.org/10.1063/5.0022919
[3] Doblhoff et al, J. Chem. Theory Comput. 13, 7, 3208–3219 (2017), https://doi.org/10.1021/acs.jctc.7b00344
[4] this work (linked publication) (see SI) using data from 
    Diaz et al, Science 326, 5954, 832 (2009), https://doi.org/10.1126/science.1178722 and
    Doblhoff et al, J. Chem. Theory Comput. 13, 7, 3208–3219 (2017), https://doi.org/10.1021/acs.jctc.7b00344
[5] this work (linked publication) (see SI) using data from 
    Powell et al, J. Phys. Chem. Lett. 2024, 15, 1, 307–315 (2024), https://doi.org/10.1021/acs.jpclett.3c02972 and
    Powell et al, J. Chem. Phys. 153, 224701 (2020), https://doi.org/10.1063/5.0022919
"""
print(references)

#print dataframes to csv
barriers.to_csv("barriers_summary.csv")
refs.to_csv("barriers_references.csv")
f=open("barriers_references_list.txt", "w")
f.write(references)
f.close

f=open("barriers_summary.txt", "w")
f.write("DATA:\n")
f.write(barriers.to_string())
f.write("\n\n")
f.write("REFERENCES:\n")
f.write(refs.to_string())
f.write("\n")
f.write(references)
f.close



