import os
import numpy as np
import ase.io
import ase.build
import dataset
import copy
import pickle
import matplotlib.pyplot as plt
from scipy.optimize import curve_fit

#this is just needed to change the font size in the figures
SMALL_SIZE = 8#12
MEDIUM_SIZE = 8#14
BIGGER_SIZE = 10#16

plt.rc('font', size=SMALL_SIZE)          # controls default text sizes
plt.rc('axes', titlesize=SMALL_SIZE)     # fontsize of the axes title
plt.rc('axes', labelsize=MEDIUM_SIZE)    # fontsize of the x and y labels
plt.rc('xtick', labelsize=SMALL_SIZE)    # fontsize of the tick labels
plt.rc('ytick', labelsize=SMALL_SIZE)    # fontsize of the tick labels
plt.rc('legend', fontsize=SMALL_SIZE)    # legend fontsize
plt.rc('figure', titlesize=BIGGER_SIZE)  # fontsize of the figure title


database_file="job_database_H2onAl_flat.db"


def get_geom(geom, vacuum, layers):
    geom_text=get_orig_geom(geom)
    if vacuum == 'standard' and layers == 'standard':
        return geom_text
    else:
        #adjust number of layers
        f = open('tmp', 'w')
        f.write(geom_text)
        f.close()
        atoms = ase.io.read('tmp', format='vasp')
        os.remove('tmp')
        if layers in [4,6,8]:
            #delete layers that are not needed
            height = set(atoms.positions[:,2])
            height = list(height)
            del_height = height[int(1+layers/2):int(11-layers/2)]
            del atoms[[atom.index for atom in atoms if atom.position[2] in del_height]]
            #shift remaining layers together again
            for i,atom in enumerate (atoms):
                if atom.position[2]>del_height[0]:
                    atoms.positions[i,2]=atoms.positions[i,2]-height[int(11-layers/2)]+height[int(1+layers/2)]
            #adjust vacuum height
            atoms.cell[2,2]=atoms.cell[2,2]-height[int(11-layers/2)]+height[int(1+layers/2)]
        if not vacuum == 'standard':
            #shift all atoms down
            atoms.positions[:,2] = atoms.positions[:,2]-12+vacuum/2
            #adjust vacuum height
            atoms.cell[2,2]=atoms.cell[2,2]-24+vacuum
            #if geom='asy': shift H atoms
            if geom == 'asy':
                atoms.positions[-1,2]=vacuum/6
                atoms.positions[-2,2]=vacuum/6
                atoms.positions[-3,2]=atoms.cell[2,2]-vacuum/6
                atoms.positions[-4,2]=atoms.cell[2,2]-vacuum/6
        filename = 'tmp'
        ase.io.write(filename, atoms, format = 'vasp')
        with open(filename, 'r') as f:
            geom_text = f.read()
        os.remove(filename)
        return geom_text


def get_orig_geom(geom):
#the following are the geom files used by Andy in the 2020 paper. They are taken from
#/2020_JCP_H2onAl110/FigS11/<xxx>/POSCAR on pubs, where
#<xxx>=[ASY, TS1, TS2,  hollow_phi0.0_theta90.0, ontop_phi90.0_theta90.0, longbridge_phi45.0_theta90.0, shortbridge_phi0.0_theta90.0]
    if geom == 'asy':
        geomtext = """Al  H
 1.0000000000000000
     8.0307999999999993    0.0000000000000000    0.0000000000000000
     0.0000000000000000    5.6786331383529260    0.0000000000000000
     0.0000000000000000    0.0000000000000000   36.7282999999999973
  40   4
Selective dynamics
Cartesian
  2.0076999999999998  1.4196582845882315 12.0000000000000000   F   F   F
  6.0230999999999995  1.4196582845882315 12.0000000000000000   F   F   F
  2.0076999999999998  4.2589748537646948 12.0000000000000000   F   F   F
  6.0230999999999995  4.2589748537646948 12.0000000000000000   F   F   F
  0.0000000000000000  0.0000000000000000 13.3367000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 13.3367000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 13.3367000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 13.3367000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 14.8149000000000015   F   F   F
  6.0230999999999995  1.4196582845882315 14.8149000000000015   F   F   F
  2.0076999999999998  4.2589748537646948 14.8149000000000015   F   F   F
  6.0230999999999995  4.2589748537646948 14.8149000000000015   F   F   F
  0.0000000000000000  0.0000000000000000 16.2346000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 16.2346000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 16.2346000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 16.2346000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 17.6542999999999992   F   F   F
  6.0230999999999995  1.4196582845882315 17.6542999999999992   F   F   F
  2.0076999999999998  4.2589748537646948 17.6542999999999992   F   F   F
  6.0230999999999995  4.2589748537646948 17.6542999999999992   F   F   F
  0.0000000000000000  0.0000000000000000 19.0739999999999981   F   F   F
  4.0153999999999996  0.0000000000000000 19.0739999999999981   F   F   F
  0.0000000000000000  2.8393165691764630 19.0739999999999981   F   F   F
  4.0153999999999996  2.8393165691764630 19.0739999999999981   F   F   F
  2.0076999999999998  1.4196582845882315 20.4936999999999969   F   F   F
  6.0230999999999995  1.4196582845882315 20.4936999999999969   F   F   F
  2.0076999999999998  4.2589748537646948 20.4936999999999969   F   F   F
  6.0230999999999995  4.2589748537646948 20.4936999999999969   F   F   F
  0.0000000000000000  0.0000000000000000 21.9133999999999958   F   F   F
  4.0153999999999996  0.0000000000000000 21.9133999999999958   F   F   F
  0.0000000000000000  2.8393165691764630 21.9133999999999958   F   F   F
  4.0153999999999996  2.8393165691764630 21.9133999999999958   F   F   F
  2.0076999999999998  1.4196582845882315 23.3915999999999968   F   F   F
  6.0230999999999995  1.4196582845882315 23.3915999999999968   F   F   F
  2.0076999999999998  4.2589748537646948 23.3915999999999968   F   F   F
  6.0230999999999995  4.2589748537646948 23.3915999999999968   F   F   F
  0.0000000000000000  0.0000000000000000 24.7282999999999973   F   F   F
  4.0153999999999996  0.0000000000000000 24.7282999999999973   F   F   F
  0.0000000000000000  2.8393165691764630 24.7282999999999973   F   F   F
  4.0153999999999996  2.8393165691764630 24.7282999999999973   F   F   F
  1.6371999999999998  0.0000000000000000 32.7282999999999973   T   T   T
  2.3781999999999996  0.0000000000000000 32.7282999999999973   T   T   T
  3.6448999999999998  1.4196582845882315  4.0000000000000000   T   T   T
  4.3858999999999995  1.4196582845882315  4.0000000000000000   T   T   T
  """
    elif geom == 'ts1':
        geomtext = """Al  H
 1.0000000000000000
     8.0307999999999993    0.0000000000000000    0.0000000000000000
     0.0000000000000000    5.6786331383529260    0.0000000000000000
     0.0000000000000000    0.0000000000000000   36.7282999999999973
  40   4
Selective dynamics
Cartesian
  2.0076999999999998  1.4196582845882315 12.0000000000000000   F   F   F
  6.0230999999999995  1.4196582845882315 12.0000000000000000   F   F   F
  2.0076999999999998  4.2589748537646948 12.0000000000000000   F   F   F
  6.0230999999999995  4.2589748537646948 12.0000000000000000   F   F   F
  0.0000000000000000  0.0000000000000000 13.3367000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 13.3367000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 13.3367000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 13.3367000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 14.8149000000000015   F   F   F
  6.0230999999999995  1.4196582845882315 14.8149000000000015   F   F   F
  2.0076999999999998  4.2589748537646948 14.8149000000000015   F   F   F
  6.0230999999999995  4.2589748537646948 14.8149000000000015   F   F   F
  0.0000000000000000  0.0000000000000000 16.2346000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 16.2346000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 16.2346000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 16.2346000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 17.6542999999999992   F   F   F
  6.0230999999999995  1.4196582845882315 17.6542999999999992   F   F   F
  2.0076999999999998  4.2589748537646948 17.6542999999999992   F   F   F
  6.0230999999999995  4.2589748537646948 17.6542999999999992   F   F   F
  0.0000000000000000  0.0000000000000000 19.0739999999999981   F   F   F
  4.0153999999999996  0.0000000000000000 19.0739999999999981   F   F   F
  0.0000000000000000  2.8393165691764630 19.0739999999999981   F   F   F
  4.0153999999999996  2.8393165691764630 19.0739999999999981   F   F   F
  2.0076999999999998  1.4196582845882315 20.4936999999999969   F   F   F
  6.0230999999999995  1.4196582845882315 20.4936999999999969   F   F   F
  2.0076999999999998  4.2589748537646948 20.4936999999999969   F   F   F
  6.0230999999999995  4.2589748537646948 20.4936999999999969   F   F   F
  0.0000000000000000  0.0000000000000000 21.9133999999999958   F   F   F
  4.0153999999999996  0.0000000000000000 21.9133999999999958   F   F   F
  0.0000000000000000  2.8393165691764630 21.9133999999999958   F   F   F
  4.0153999999999996  2.8393165691764630 21.9133999999999958   F   F   F
  2.0076999999999998  1.4196582845882315 23.3915999999999968   F   F   F
  6.0230999999999995  1.4196582845882315 23.3915999999999968   F   F   F
  2.0076999999999998  4.2589748537646948 23.3915999999999968   F   F   F
  6.0230999999999995  4.2589748537646948 23.3915999999999968   F   F   F
  0.0000000000000000  0.0000000000000000 24.7282999999999973   F   F   F
  4.0153999999999996  0.0000000000000000 24.7282999999999973   F   F   F
  0.0000000000000000  2.8393165691764630 24.7282999999999973   F   F   F
  4.0153999999999996  2.8393165691764630 24.7282999999999973   F   F   F
  1.3406999999999998  0.0000000000000000 25.8462999999999958   T   T   T
  2.6746999999999996  0.0000000000000000 25.8462999999999958   T   T   T
  3.3483999999999998  1.4196582845882315 10.8819999999999997   T   T   T
  4.6823999999999995  1.4196582845882315 10.8819999999999997   T   T   T
  """
    elif geom == 'ts2':
        geomtext = """Al  H
 1.0000000000000000
     8.0307999999999993    0.0000000000000000    0.0000000000000000
     0.0000000000000000    5.6786331383529260    0.0000000000000000
     0.0000000000000000    0.0000000000000000   36.7282999999999973
  40   4
Selective dynamics
Cartesian
  2.0076999999999998  1.4196582845882315 12.0000000000000000   F   F   F
  6.0230999999999995  1.4196582845882315 12.0000000000000000   F   F   F
  2.0076999999999998  4.2589748537646948 12.0000000000000000   F   F   F
  6.0230999999999995  4.2589748537646948 12.0000000000000000   F   F   F
  0.0000000000000000  0.0000000000000000 13.3367000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 13.3367000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 13.3367000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 13.3367000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 14.8149000000000015   F   F   F
  6.0230999999999995  1.4196582845882315 14.8149000000000015   F   F   F
  2.0076999999999998  4.2589748537646948 14.8149000000000015   F   F   F
  6.0230999999999995  4.2589748537646948 14.8149000000000015   F   F   F
  0.0000000000000000  0.0000000000000000 16.2346000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 16.2346000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 16.2346000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 16.2346000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 17.6542999999999992   F   F   F
  6.0230999999999995  1.4196582845882315 17.6542999999999992   F   F   F
  2.0076999999999998  4.2589748537646948 17.6542999999999992   F   F   F
  6.0230999999999995  4.2589748537646948 17.6542999999999992   F   F   F
  0.0000000000000000  0.0000000000000000 19.0739999999999981   F   F   F
  4.0153999999999996  0.0000000000000000 19.0739999999999981   F   F   F
  0.0000000000000000  2.8393165691764630 19.0739999999999981   F   F   F
  4.0153999999999996  2.8393165691764630 19.0739999999999981   F   F   F
  2.0076999999999998  1.4196582845882315 20.4936999999999969   F   F   F
  6.0230999999999995  1.4196582845882315 20.4936999999999969   F   F   F
  2.0076999999999998  4.2589748537646948 20.4936999999999969   F   F   F
  6.0230999999999995  4.2589748537646948 20.4936999999999969   F   F   F
  0.0000000000000000  0.0000000000000000 21.9133999999999958   F   F   F
  4.0153999999999996  0.0000000000000000 21.9133999999999958   F   F   F
  0.0000000000000000  2.8393165691764630 21.9133999999999958   F   F   F
  4.0153999999999996  2.8393165691764630 21.9133999999999958   F   F   F
  2.0076999999999998  1.4196582845882315 23.3915999999999968   F   F   F
  6.0230999999999995  1.4196582845882315 23.3915999999999968   F   F   F
  2.0076999999999998  4.2589748537646948 23.3915999999999968   F   F   F
  6.0230999999999995  4.2589748537646948 23.3915999999999968   F   F   F
  0.0000000000000000  0.0000000000000000 24.7282999999999973   F   F   F
  4.0153999999999996  0.0000000000000000 24.7282999999999973   F   F   F
  0.0000000000000000  2.8393165691764630 24.7282999999999973   F   F   F
  4.0153999999999996  2.8393165691764630 24.7282999999999973   F   F   F
 -0.0000000000000000  0.8796582845882315 26.2962999999999987   T   T   T
  0.0000000000000000  1.9596582845882315 26.2962999999999987   T   T   T
  2.0076999999999998  2.2993165691764630 10.4320000000000004   T   T   T
  2.0076999999999998  3.3793165691764631 10.4320000000000004   T   T   T
  """
    elif geom == 'ts3':
        geomtext = """Al  H
 1.0000000000000000
     8.0307999999999993    0.0000000000000000    0.0000000000000000
     0.0000000000000000    5.6786331383529260    0.0000000000000000
     0.0000000000000000    0.0000000000000000   36.7282999999999973
  40   4
Selective dynamics
Cartesian
  2.0076999999999998  1.4196582845882315 12.0000000000000000   F   F   F
  6.0230999999999995  1.4196582845882315 12.0000000000000000   F   F   F
  2.0076999999999998  4.2589748537646948 12.0000000000000000   F   F   F
  6.0230999999999995  4.2589748537646948 12.0000000000000000   F   F   F
  0.0000000000000000  0.0000000000000000 13.3367000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 13.3367000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 13.3367000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 13.3367000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 14.8149000000000015   F   F   F
  6.0230999999999995  1.4196582845882315 14.8149000000000015   F   F   F
  2.0076999999999998  4.2589748537646948 14.8149000000000015   F   F   F
  6.0230999999999995  4.2589748537646948 14.8149000000000015   F   F   F
  0.0000000000000000  0.0000000000000000 16.2346000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 16.2346000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 16.2346000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 16.2346000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 17.6542999999999992   F   F   F
  6.0230999999999995  1.4196582845882315 17.6542999999999992   F   F   F
  2.0076999999999998  4.2589748537646948 17.6542999999999992   F   F   F
  6.0230999999999995  4.2589748537646948 17.6542999999999992   F   F   F
  0.0000000000000000  0.0000000000000000 19.0739999999999981   F   F   F
  4.0153999999999996  0.0000000000000000 19.0739999999999981   F   F   F
  0.0000000000000000  2.8393165691764630 19.0739999999999981   F   F   F
  4.0153999999999996  2.8393165691764630 19.0739999999999981   F   F   F
  2.0076999999999998  1.4196582845882315 20.4936999999999969   F   F   F
  6.0230999999999995  1.4196582845882315 20.4936999999999969   F   F   F
  2.0076999999999998  4.2589748537646948 20.4936999999999969   F   F   F
  6.0230999999999995  4.2589748537646948 20.4936999999999969   F   F   F
  0.0000000000000000  0.0000000000000000 21.9133999999999958   F   F   F
  4.0153999999999996  0.0000000000000000 21.9133999999999958   F   F   F
  0.0000000000000000  2.8393165691764630 21.9133999999999958   F   F   F
  4.0153999999999996  2.8393165691764630 21.9133999999999958   F   F   F
  2.0076999999999998  1.4196582845882315 23.3915999999999968   F   F   F
  6.0230999999999995  1.4196582845882315 23.3915999999999968   F   F   F
  2.0076999999999998  4.2589748537646948 23.3915999999999968   F   F   F
  6.0230999999999995  4.2589748537646948 23.3915999999999968   F   F   F
  0.0000000000000000  0.0000000000000000 24.7282999999999973   F   F   F
  4.0153999999999996  0.0000000000000000 24.7282999999999973   F   F   F
  0.0000000000000000  2.8393165691764630 24.7282999999999973   F   F   F
  4.0153999999999996  2.8393165691764630 24.7282999999999973   F   F   F
  1.3851999999999998  1.4196582845882315 25.3432999999999957   T   T   T
  2.6301999999999999  1.4196582845882315 25.3432999999999957   T   T   T
  3.3928999999999996  2.8393165691764630 11.3849999999999998   T   T   T
  4.6379000000000001  2.8393165691764630 11.3849999999999998   T   T   T
  """
    elif geom == 'ts4':
        geomtext = """Al  H
 1.0000000000000000
     8.0307999999999993    0.0000000000000000    0.0000000000000000
     0.0000000000000000    5.6786331383529260    0.0000000000000000
     0.0000000000000000    0.0000000000000000   36.7282999999999973
  40   4
Selective dynamics
Cartesian
  2.0076999999999998  1.4196582845882315 12.0000000000000000   F   F   F
  6.0230999999999995  1.4196582845882315 12.0000000000000000   F   F   F
  2.0076999999999998  4.2589748537646948 12.0000000000000000   F   F   F
  6.0230999999999995  4.2589748537646948 12.0000000000000000   F   F   F
  0.0000000000000000  0.0000000000000000 13.3367000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 13.3367000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 13.3367000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 13.3367000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 14.8149000000000015   F   F   F
  6.0230999999999995  1.4196582845882315 14.8149000000000015   F   F   F
  2.0076999999999998  4.2589748537646948 14.8149000000000015   F   F   F
  6.0230999999999995  4.2589748537646948 14.8149000000000015   F   F   F
  0.0000000000000000  0.0000000000000000 16.2346000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 16.2346000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 16.2346000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 16.2346000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 17.6542999999999992   F   F   F
  6.0230999999999995  1.4196582845882315 17.6542999999999992   F   F   F
  2.0076999999999998  4.2589748537646948 17.6542999999999992   F   F   F
  6.0230999999999995  4.2589748537646948 17.6542999999999992   F   F   F
  0.0000000000000000  0.0000000000000000 19.0739999999999981   F   F   F
  4.0153999999999996  0.0000000000000000 19.0739999999999981   F   F   F
  0.0000000000000000  2.8393165691764630 19.0739999999999981   F   F   F
  4.0153999999999996  2.8393165691764630 19.0739999999999981   F   F   F
  2.0076999999999998  1.4196582845882315 20.4936999999999969   F   F   F
  6.0230999999999995  1.4196582845882315 20.4936999999999969   F   F   F
  2.0076999999999998  4.2589748537646948 20.4936999999999969   F   F   F
  6.0230999999999995  4.2589748537646948 20.4936999999999969   F   F   F
  0.0000000000000000  0.0000000000000000 21.9133999999999958   F   F   F
  4.0153999999999996  0.0000000000000000 21.9133999999999958   F   F   F
  0.0000000000000000  2.8393165691764630 21.9133999999999958   F   F   F
  4.0153999999999996  2.8393165691764630 21.9133999999999958   F   F   F
  2.0076999999999998  1.4196582845882315 23.3915999999999968   F   F   F
  6.0230999999999995  1.4196582845882315 23.3915999999999968   F   F   F
  2.0076999999999998  4.2589748537646948 23.3915999999999968   F   F   F
  6.0230999999999995  4.2589748537646948 23.3915999999999968   F   F   F
  0.0000000000000000  0.0000000000000000 24.7282999999999973   F   F   F
  4.0153999999999996  0.0000000000000000 24.7282999999999973   F   F   F
  0.0000000000000000  2.8393165691764630 24.7282999999999973   F   F   F
  4.0153999999999996  2.8393165691764630 24.7282999999999973   F   F   F
  0.0000000000000000 -0.6840000000000001 26.2922999999999973   T   T   T
  0.0000000000000000  0.6840000000000001 26.2922999999999973   T   T   T
  2.0076999999999998  0.7356582845882315 10.4359999999999999   T   T   T
  2.0076999999999998  2.1036582845882315 10.4359999999999999   T   T   T
  """
    elif geom == 'ts5':
        geomtext = """Al  H
 1.0000000000000000
     8.0307999999999993    0.0000000000000000    0.0000000000000000
     0.0000000000000000    5.6786331383529260    0.0000000000000000
     0.0000000000000000    0.0000000000000000   36.7282999999999973
  40   4
Selective dynamics
Cartesian
  2.0076999999999998  1.4196582845882315 12.0000000000000000   F   F   F
  6.0230999999999995  1.4196582845882315 12.0000000000000000   F   F   F
  2.0076999999999998  4.2589748537646948 12.0000000000000000   F   F   F
  6.0230999999999995  4.2589748537646948 12.0000000000000000   F   F   F
  0.0000000000000000  0.0000000000000000 13.3367000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 13.3367000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 13.3367000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 13.3367000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 14.8149000000000015   F   F   F
  6.0230999999999995  1.4196582845882315 14.8149000000000015   F   F   F
  2.0076999999999998  4.2589748537646948 14.8149000000000015   F   F   F
  6.0230999999999995  4.2589748537646948 14.8149000000000015   F   F   F
  0.0000000000000000  0.0000000000000000 16.2346000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 16.2346000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 16.2346000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 16.2346000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 17.6542999999999992   F   F   F
  6.0230999999999995  1.4196582845882315 17.6542999999999992   F   F   F
  2.0076999999999998  4.2589748537646948 17.6542999999999992   F   F   F
  6.0230999999999995  4.2589748537646948 17.6542999999999992   F   F   F
  0.0000000000000000  0.0000000000000000 19.0739999999999981   F   F   F
  4.0153999999999996  0.0000000000000000 19.0739999999999981   F   F   F
  0.0000000000000000  2.8393165691764630 19.0739999999999981   F   F   F
  4.0153999999999996  2.8393165691764630 19.0739999999999981   F   F   F
  2.0076999999999998  1.4196582845882315 20.4936999999999969   F   F   F
  6.0230999999999995  1.4196582845882315 20.4936999999999969   F   F   F
  2.0076999999999998  4.2589748537646948 20.4936999999999969   F   F   F
  6.0230999999999995  4.2589748537646948 20.4936999999999969   F   F   F
  0.0000000000000000  0.0000000000000000 21.9133999999999958   F   F   F
  4.0153999999999996  0.0000000000000000 21.9133999999999958   F   F   F
  0.0000000000000000  2.8393165691764630 21.9133999999999958   F   F   F
  4.0153999999999996  2.8393165691764630 21.9133999999999958   F   F   F
  2.0076999999999998  1.4196582845882315 23.3915999999999968   F   F   F
  6.0230999999999995  1.4196582845882315 23.3915999999999968   F   F   F
  2.0076999999999998  4.2589748537646948 23.3915999999999968   F   F   F
  6.0230999999999995  4.2589748537646948 23.3915999999999968   F   F   F
  0.0000000000000000  0.0000000000000000 24.7282999999999973   F   F   F
  4.0153999999999996  0.0000000000000000 24.7282999999999973   F   F   F
  0.0000000000000000  2.8393165691764630 24.7282999999999973   F   F   F
  4.0153999999999996  2.8393165691764630 24.7282999999999973   F   F   F
  1.5265138354025540 -0.4811861645974455 25.5142999999999986   T   T   T
  2.4888861645974454  0.4811861645974456 25.5142999999999986   T   T   T
  3.5342138354025536  0.9384721199907859 11.2140000000000004   T   T   T
  4.4965861645974456  1.9008444491856771 11.2140000000000004   T   T   T
  """
    elif geom == 'ts6':
        geomtext = """Al  H
 1.0000000000000000
     8.0307999999999993    0.0000000000000000    0.0000000000000000
     0.0000000000000000    5.6786331383529260    0.0000000000000000
     0.0000000000000000    0.0000000000000000   36.7282999999999973
  40   4
Selective dynamics
Cartesian
  2.0076999999999998  1.4196582845882315 12.0000000000000000   F   F   F
  6.0230999999999995  1.4196582845882315 12.0000000000000000   F   F   F
  2.0076999999999998  4.2589748537646948 12.0000000000000000   F   F   F
  6.0230999999999995  4.2589748537646948 12.0000000000000000   F   F   F
  0.0000000000000000  0.0000000000000000 13.3367000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 13.3367000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 13.3367000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 13.3367000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 14.8149000000000015   F   F   F
  6.0230999999999995  1.4196582845882315 14.8149000000000015   F   F   F
  2.0076999999999998  4.2589748537646948 14.8149000000000015   F   F   F
  6.0230999999999995  4.2589748537646948 14.8149000000000015   F   F   F
  0.0000000000000000  0.0000000000000000 16.2346000000000004   F   F   F
  4.0153999999999996  0.0000000000000000 16.2346000000000004   F   F   F
  0.0000000000000000  2.8393165691764630 16.2346000000000004   F   F   F
  4.0153999999999996  2.8393165691764630 16.2346000000000004   F   F   F
  2.0076999999999998  1.4196582845882315 17.6542999999999992   F   F   F
  6.0230999999999995  1.4196582845882315 17.6542999999999992   F   F   F
  2.0076999999999998  4.2589748537646948 17.6542999999999992   F   F   F
  6.0230999999999995  4.2589748537646948 17.6542999999999992   F   F   F
  0.0000000000000000  0.0000000000000000 19.0739999999999981   F   F   F
  4.0153999999999996  0.0000000000000000 19.0739999999999981   F   F   F
  0.0000000000000000  2.8393165691764630 19.0739999999999981   F   F   F
  4.0153999999999996  2.8393165691764630 19.0739999999999981   F   F   F
  2.0076999999999998  1.4196582845882315 20.4936999999999969   F   F   F
  6.0230999999999995  1.4196582845882315 20.4936999999999969   F   F   F
  2.0076999999999998  4.2589748537646948 20.4936999999999969   F   F   F
  6.0230999999999995  4.2589748537646948 20.4936999999999969   F   F   F
  0.0000000000000000  0.0000000000000000 21.9133999999999958   F   F   F
  4.0153999999999996  0.0000000000000000 21.9133999999999958   F   F   F
  0.0000000000000000  2.8393165691764630 21.9133999999999958   F   F   F
  4.0153999999999996  2.8393165691764630 21.9133999999999958   F   F   F
  2.0076999999999998  1.4196582845882315 23.3915999999999968   F   F   F
  6.0230999999999995  1.4196582845882315 23.3915999999999968   F   F   F
  2.0076999999999998  4.2589748537646948 23.3915999999999968   F   F   F
  6.0230999999999995  4.2589748537646948 23.3915999999999968   F   F   F
  0.0000000000000000  0.0000000000000000 24.7282999999999973   F   F   F
  4.0153999999999996  0.0000000000000000 24.7282999999999973   F   F   F
  0.0000000000000000  2.8393165691764630 24.7282999999999973   F   F   F
  4.0153999999999996  2.8393165691764630 24.7282999999999973   F   F   F
 -0.5770000000000000  1.4196582845882315 25.9032999999999980   T   T   T
  0.5770000000000000  1.4196582845882315 25.9032999999999980   T   T   T
  1.4306999999999999  2.8393165691764630 10.8249999999999993   T   T   T
  2.5846999999999998  2.8393165691764630 10.8249999999999993   T   T   T
  """
    return geomtext



#The following list contains combinations of ecut and vaccum for which the calculations were done (max k range: 4-12)
layers_list = ['standard']
#xc_list = ['pbe', 'rpbe', 'pbe-vdw-df', 'rpbe-vdw-df', 'revtpss', 'beef-vdw', 'scan', 'pbe-vdw-df2', 'm06l']
xc_list = ['m06l']
smearing = 'mp'
smearing_val = 0.1 #eV
pseudo = "POTCAR_Al_H"
ecut_list = [600]
k_list = [17]
vacuum_list = ['standard']

fig, ax = plt.subplots(nrows=1, ncols=1, figsize=(3.5,3))
fig2, ax2 = plt.subplots(nrows=1, ncols=1, figsize=(3.5,3))
for i, geom in enumerate(['ts1', 'ts2', 'ts3', 'ts4', 'ts5', 'ts6']):
    names_list = []
    barriers={}
    ids={}
    #loop over ecut
    for ecut in ecut_list:
        #loop over vaccum
        for iterator in range(len(vacuum_list)):
            vacuum = vacuum_list[iterator]
            layers = layers_list[iterator]
            for xc in xc_list:
                name = "{}".format(xc)
                names_list.append(name)
                barriers[name]={}
                ids[name]={}
                #loop over k
                for k in k_list:
                    energy={}
                    myid={}
                    #loop over configs (asy and geom)
                    for config in ['asy', geom]:
                        geom_text = get_geom(config,vacuum,layers)
                        #create job record
                        if xc=='beef-vdw':
                            program = 'vasp6.3.0-beef'
                        elif  xc=='m06l':
                            program = 'vasp6.3.2'
                        else:
                            program = 'vasp6.3.0'
                        job_record={'program': program,\
                                'scf': 'single point',\
                                'nkx': k,\
                                'nky': k,\
                                'nkz':1,\
                                'ecut':ecut,\
                                'xc':xc,\
                                'smearing':smearing,\
                                'smearing val':smearing_val,\
                                'geom':geom_text,\
                                'pseudofiles': pseudo}
                
                        #retreive job record to database
                        with dataset.connect('sqlite:///'+database_file) as database:
                            jobs = list(database['data'].find(**job_record))
                            if len(jobs)==1:
                                if jobs[0]['status']=='done':
                                    energy[config]=jobs[0]['energy']
                                    myid[config]=jobs[0]['id']
        
                    try:
                        barriers[name][k]=(float(energy[geom])-float(energy['asy']))*0.5 #multipy with 0.5 as there are 2 H2
                        ids[name][k] = [myid['asy'], myid[geom]]
                    except:
                        barriers[name][k]=float('nan')
                        ids[name][k] = float('nan')

    #print output
    print("-----------{}---------------".format(geom))    
    header="   "
    for name in names_list:
        header+="\t{:8s}".format(name)
    print("ids")
    print(header)
    line=geom
    for name in names_list:
        line+="\t{:10}".format(str(ids[name][k]))
    print(line)
    print("")
    print("barriers")
    print(header)
    line=geom
    for name in names_list:
        line+="\t{:10.6f}".format(barriers[name][k])
    print(line)
    print("")

    if i==0:
        barriers_H2onAl_DFT = {}
        barriers_H2onAl_DFT[name]=[]
    for name in names_list:
        barriers_H2onAl_DFT[name].append(barriers[name][k])
f = open('H2onAl_DFT.pkl', 'wb')
pickle.dump(barriers_H2onAl_DFT, f)
f.close()






