import os
import numpy as np
import ase.io
import ase.build
import dataset
import pickle
import copy
import matplotlib.pyplot as plt
from scipy.optimize import curve_fit

#this is just needed to change the font size in the figures
SMALL_SIZE = 8#12
MEDIUM_SIZE = 8#14
BIGGER_SIZE = 10#16

plt.rc('font', size=SMALL_SIZE)          # controls default text sizes
plt.rc('axes', titlesize=SMALL_SIZE)     # fontsize of the axes title
plt.rc('axes', labelsize=MEDIUM_SIZE)    # fontsize of the x and y labels
plt.rc('xtick', labelsize=SMALL_SIZE)    # fontsize of the tick labels
plt.rc('ytick', labelsize=SMALL_SIZE)    # fontsize of the tick labels
plt.rc('legend', fontsize=SMALL_SIZE)    # legend fontsize
plt.rc('figure', titlesize=BIGGER_SIZE)  # fontsize of the figure title


database_file="job_database_H2onCu_flat.db"

def get_geom(geom, vacuum, layers):
    geom_text=get_orig_geom(geom)
    if vacuum == 'standard' and layers == 'standard':
        return geom_text
    else:
        #adjust number of layers
        f = open('tmp', 'w')
        f.write(geom_text)
        f.close()
        atoms = ase.io.read('tmp', format='vasp')
        os.remove('tmp')
        if layers in [3]:
            #delete layers that are not needed
            height = set(atoms.positions[:,2])
            height = list(height)
            del_height = height[0]
            del atoms[[atom.index for atom in atoms if atom.position[2] in del_height]]
            #adjust positions
            for atom in atoms:
                atom.positions[2]=atom.positions[2]-height[1]+height[0]
            #adjust vacuum height
            atoms.cell[2,2]=atoms.cell[2,2]-height[1]+height[0]
        if not vacuum == 'standard':
            #shift all atoms down
            atoms.positions[:,2] = atoms.positions[:,2]-6+vacuum/2.
            #adjust vacuum height
            atoms.cell[2,2]=atoms.cell[2,2]-12+vacuum
            #if geom='asy': shift H atoms
            if geom == 'asy':
                atoms.positions[-1,2]=atoms.positions[-1,2]-6+vacuum/2.
                atoms.positions[-2,2]=atoms.positions[-2,2]-6+vacuum/2.
        filename = 'tmp'
        ase.io.write(filename, atoms, format = 'vasp')
        with open(filename, 'r') as f:
            geom_text = f.read()
        os.remove(filename)
        return geom_text


def get_orig_geom(geom):
    #geometry taken from analysis_04.ipynb as used for the analysis of the QMC results in the 2017 paper of H2 on Cu(111)
    positionsDict={}
    positionsDict['asy']=[]
    positionsDict['asy'].append({"atom":'Cu', "position":[   0.000000000,   0.000000000,   0.000000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[   2.552655436,   0.000000000,   0.000000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[  -1.276327718,   2.210664573,   0.000000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[   1.276327718,   2.210664573,   0.000000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[   1.276327756,   0.736888213,  -2.063000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[   3.828983193,   0.736888213,  -2.063000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[   0.000000038,   2.947552786,  -2.063000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[   2.552655474,   2.947552786,  -2.063000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[   0.000000000,   1.473776426,  -4.143000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[   2.552655436,   1.473776426,  -4.143000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[  -1.276327718,   3.684440999,  -4.143000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[   1.276327718,   3.684440999,  -4.143000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[   0.000000000,   0.000000000,  -6.227000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[   2.552655436,   0.000000000,  -6.227000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[  -1.276327718,   2.210664573,  -6.227000000]})
    positionsDict['asy'].append({"atom":'Cu', "position":[   1.276327718,   2.210664573,  -6.227000000]})
    positionsDict['ts1']=copy.deepcopy(positionsDict['asy'])
    positionsDict['asy'].append({"atom":'H', "position":[    1.276327702,    .370720000,   6.499999984]})
    positionsDict['asy'].append({"atom":'H', "position":[    1.276327735,   -.370720000,   6.500000016]})
    positionsDict['ts1'].append({"atom":'H', "position":[       1.276327696,   0.516000000,   1.163999977]})
    positionsDict['ts1'].append({"atom":'H', "position":[       1.276327741,  -0.516000000,   1.164000023]})

    v1=[ 5.105310873,    0.000000000,    0.000000000]
    v2=[-2.552655436,    4.421329147,    0.000000000]
    v3=[ 0.000000000,    0.000000000,   19.227000000]

    #shift atom into center of simulation cell in z direction (according to asymt geometry)
    z=[]
    for atom in positionsDict['asy']:
        z.append(atom['position'][2])
    shiftz=v3[2]/2-(min(z)+max(z))/2

    for atom in positionsDict[geom]:
        atom['position'][2]=atom['position'][2]+shiftz

    #transfer to an ase geometry
    atoms=ase.Atoms('Cu16H2', positions = [atom['position'] for atom in positionsDict[geom]], cell = [v1,v2,v3])

    filename = 'tmp'
    ase.io.write(filename, atoms, format = 'vasp')
    with open(filename, 'r') as f:
        geom_text = f.read()
    os.remove(filename)
    return geom_text


#The following list contains combinations of ecut and vaccum for which the calculations were done (max k range: 4-12)
layers_list = ['standard']
xc_list = ['pbe', 'rpbe', 'pbe-vdw-df', 'rpbe-vdw-df', 'revtpss', 'beef-vdw', 'scan', 'm06l']
smearing = 'mp'
smearing_val = 0.1 #eV
pseudo = "POTCAR_Cu_H"
ecut_list = [600]
k_list = [17]
vacuum_list = ['standard']

fig, ax = plt.subplots(nrows=1, ncols=1, figsize=(3.5,3))
fig2, ax2 = plt.subplots(nrows=1, ncols=1, figsize=(3.5,3))
names_list = []
for i, geom in enumerate(['ts1']):
    barriers={}
    ids={}
    #loop over ecut
    for ecut in ecut_list:
        #loop over vaccum
        for iterator in range(len(vacuum_list)):
            vacuum = vacuum_list[iterator]
            layers = layers_list[iterator]
            for xc in xc_list:
                name = "{}".format(xc)
                names_list.append(name)
                barriers[name]={}
                ids[name]={}
                #loop over k
                for k in k_list:
                    energy={}
                    myid={}
                    #loop over configs (asy and geom)
                    for config in ['asy', geom]:
                        geom_text = get_geom(config,vacuum,layers)
                        #create job record
                        if xc=='beef-vdw':
                            program = 'vasp6.3.0-beef'
                        elif xc=='m06l':
                            program = 'vasp6.3.2'
                        else:
                            program = 'vasp6.3.0'
                        job_record={'program': program,\
                                'scf': 'single point',\
                                'nkx': k,\
                                'nky': k,\
                                'nkz':1,\
                                'ecut':ecut,\
                                'xc':xc,\
                                'smearing':smearing,\
                                'smearing val':smearing_val,\
                                'geom':geom_text,\
                                'pseudofiles': pseudo}
                
                        #retreive job record to database
                        with dataset.connect('sqlite:///'+database_file) as database:
                            jobs = list(database['data'].find(**job_record))
                            if len(jobs)==1:
                                if jobs[0]['status']=='done':
                                    energy[config]=jobs[0]['energy']
                                    myid[config]=jobs[0]['id']
        
                    try:
                        barriers[name][k]=(float(energy[geom])-float(energy['asy']))
                        ids[name][k] = [myid['asy'], myid[geom]]
                    except:
                        barriers[name][k]=float('nan')
                        ids[name][k] = float('nan')

    #print output
    print("-----------{}---------------".format(geom))    
    header="   "
    for name in names_list:
        header+="\t{:8s}".format(name)
    print("ids")
    print(header)
    line="TS1"
    for name in names_list:
        line+="\t{:10}".format(str(ids[name][k]))
    print(line)
    print("")
    print("barriers")
    print(header)
    line="TS1"
    for name in names_list:
        line+="\t{:10.6f}".format(barriers[name][k])
    print(line)
    print("")

barriers_H2onCu_DFT = {}
for name in names_list:
    barriers_H2onCu_DFT[name]=barriers[name][k]
f = open('H2onCu_DFT.pkl', 'wb')
pickle.dump(barriers_H2onCu_DFT, f)
f.close()









